<?php $icons = array();
$icons['stm']['stm14_fax'] = array("class"=>'stm14_fax',"tags"=>'stm14_fax');
$icons['stm']['stm14_bulb'] = array("class"=>'stm14_bulb',"tags"=>'stm14_bulb');
$icons['stm']['stm14_calc'] = array("class"=>'stm14_calc',"tags"=>'stm14_calc');
$icons['stm']['stm14_calendar'] = array("class"=>'stm14_calendar',"tags"=>'stm14_calendar');
$icons['stm']['stm14_country'] = array("class"=>'stm14_country',"tags"=>'stm14_country');
$icons['stm']['stm14_health'] = array("class"=>'stm14_health',"tags"=>'stm14_health');
$icons['stm']['stm14_left_arrow'] = array("class"=>'stm14_left_arrow',"tags"=>'stm14_left_arrow');
$icons['stm']['stm14_manufacturing'] = array("class"=>'stm14_manufacturing',"tags"=>'stm14_manufacturing');
$icons['stm']['stm14_office'] = array("class"=>'stm14_office',"tags"=>'stm14_office');
$icons['stm']['stm14_plane'] = array("class"=>'stm14_plane',"tags"=>'stm14_plane');
$icons['stm']['stm14_public'] = array("class"=>'stm14_public',"tags"=>'stm14_public');
$icons['stm']['stm14_quote'] = array("class"=>'stm14_quote',"tags"=>'stm14_quote');
$icons['stm']['stm14_right_arrow'] = array("class"=>'stm14_right_arrow',"tags"=>'stm14_right_arrow');
$icons['stm']['stm14_satellite'] = array("class"=>'stm14_satellite',"tags"=>'stm14_satellite');
$icons['stm']['stm14-arrow'] = array("class"=>'stm14-arrow',"tags"=>'stm14-arrow');
$icons['stm']['stn14_home'] = array("class"=>'stn14_home',"tags"=>'stn14_home');
$icons['stm']['cart_13'] = array("class"=>'cart_13',"tags"=>'cart_13');
$icons['stm']['chip_13'] = array("class"=>'chip_13',"tags"=>'chip_13');
$icons['stm']['env_13'] = array("class"=>'env_13',"tags"=>'env_13');
$icons['stm']['horse_13'] = array("class"=>'horse_13',"tags"=>'horse_13');
$icons['stm']['human_13'] = array("class"=>'human_13',"tags"=>'human_13');
$icons['stm']['mail_13'] = array("class"=>'mail_13',"tags"=>'mail_13');
$icons['stm']['phone_13_2'] = array("class"=>'phone_13_2',"tags"=>'phone_13_2');
$icons['stm']['phone_13'] = array("class"=>'phone_13',"tags"=>'phone_13');
$icons['stm']['pin_13'] = array("class"=>'pin_13',"tags"=>'pin_13');
$icons['stm']['quote_13'] = array("class"=>'quote_13',"tags"=>'quote_13');
$icons['stm']['quote2'] = array("class"=>'quote2',"tags"=>'quote2');
$icons['stm']['pin-11'] = array("class"=>'pin-11',"tags"=>'pin-11');
$icons['stm']['envelope-11'] = array("class"=>'envelope-11',"tags"=>'envelope-11');
$icons['stm']['phone-11'] = array("class"=>'phone-11',"tags"=>'phone-11');
$icons['stm']['quote8'] = array("class"=>'quote8',"tags"=>'quote8');
$icons['stm']['shopping-cart8'] = array("class"=>'shopping-cart8',"tags"=>'shopping-cart8');
$icons['stm']['aim7'] = array("class"=>'aim7',"tags"=>'aim7');
$icons['stm']['cup7'] = array("class"=>'cup7',"tags"=>'cup7');
$icons['stm']['user7'] = array("class"=>'user7',"tags"=>'user7');
$icons['stm']['docs7'] = array("class"=>'docs7',"tags"=>'docs7');
$icons['stm']['bar-graph7'] = array("class"=>'bar-graph7',"tags"=>'bar-graph7');
$icons['stm']['plant7'] = array("class"=>'plant7',"tags"=>'plant7');
$icons['stm']['lorry6'] = array("class"=>'lorry6',"tags"=>'lorry6');
$icons['stm']['lamp6'] = array("class"=>'lamp6',"tags"=>'lamp6');
$icons['stm']['building6'] = array("class"=>'building6',"tags"=>'building6');
$icons['stm']['cart6'] = array("class"=>'cart6',"tags"=>'cart6');
$icons['stm']['line-graph6'] = array("class"=>'line-graph6',"tags"=>'line-graph6');
$icons['stm']['plane6'] = array("class"=>'plane6',"tags"=>'plane6');
$icons['stm']['user'] = array("class"=>'user',"tags"=>'user');
$icons['stm']['crown'] = array("class"=>'crown',"tags"=>'crown');
$icons['stm']['cup'] = array("class"=>'cup',"tags"=>'cup');
$icons['stm']['polygon'] = array("class"=>'polygon',"tags"=>'polygon');
$icons['stm']['person-globe'] = array("class"=>'person-globe',"tags"=>'person-globe');
$icons['stm']['head'] = array("class"=>'head',"tags"=>'head');
$icons['stm']['arm-leaf'] = array("class"=>'arm-leaf',"tags"=>'arm-leaf');
$icons['stm']['phone'] = array("class"=>'phone',"tags"=>'phone');
$icons['stm']['phone6'] = array("class"=>'phone6',"tags"=>'phone6');
$icons['stm']['clock6'] = array("class"=>'clock6',"tags"=>'clock6');
$icons['stm']['pin6'] = array("class"=>'pin6',"tags"=>'pin6');
$icons['stm']['clock'] = array("class"=>'clock',"tags"=>'clock');
$icons['stm']['plus'] = array("class"=>'plus',"tags"=>'plus');
$icons['stm']['earth'] = array("class"=>'earth',"tags"=>'earth');
$icons['stm']['chart-refresh'] = array("class"=>'chart-refresh',"tags"=>'chart-refresh');
$icons['stm']['chart-monitor'] = array("class"=>'chart-monitor',"tags"=>'chart-monitor');
$icons['stm']['hexagon'] = array("class"=>'hexagon',"tags"=>'hexagon');
$icons['stm']['metals'] = array("class"=>'metals',"tags"=>'metals');
$icons['stm']['oil'] = array("class"=>'oil',"tags"=>'oil');
$icons['stm']['target'] = array("class"=>'target',"tags"=>'target');
$icons['stm']['rating_down'] = array("class"=>'rating_down',"tags"=>'rating_down');
$icons['stm']['libra'] = array("class"=>'libra',"tags"=>'libra');
$icons['stm']['diamond'] = array("class"=>'diamond',"tags"=>'diamond');
$icons['stm']['idea'] = array("class"=>'idea',"tags"=>'idea');
$icons['stm']['stats'] = array("class"=>'stats',"tags"=>'stats');
$icons['stm']['badge'] = array("class"=>'badge',"tags"=>'badge');
$icons['stm']['security'] = array("class"=>'security',"tags"=>'security');
$icons['stm']['binoculars'] = array("class"=>'binoculars',"tags"=>'binoculars');
$icons['stm']['mans'] = array("class"=>'mans',"tags"=>'mans');
$icons['stm']['nokia'] = array("class"=>'nokia',"tags"=>'nokia');
$icons['stm']['testimonials-new-2'] = array("class"=>'testimonials-new-2',"tags"=>'testimonials-new-2');
$icons['stm']['envelope'] = array("class"=>'envelope',"tags"=>'envelope');
$icons['stm']['email'] = array("class"=>'email',"tags"=>'email');
$icons['stm']['iphone'] = array("class"=>'iphone',"tags"=>'iphone');
$icons['stm']['location-2'] = array("class"=>'location-2',"tags"=>'location-2');
$icons['stm']['marker'] = array("class"=>'marker',"tags"=>'marker');
$icons['stm']['check'] = array("class"=>'check',"tags"=>'check');
$icons['stm']['truck'] = array("class"=>'truck',"tags"=>'truck');
$icons['stm']['lamp'] = array("class"=>'lamp',"tags"=>'lamp');
$icons['stm']['cart-2'] = array("class"=>'cart-2',"tags"=>'cart-2');
$icons['stm']['cart'] = array("class"=>'cart',"tags"=>'cart');
$icons['stm']['home'] = array("class"=>'home',"tags"=>'home');
$icons['stm']['graph'] = array("class"=>'graph',"tags"=>'graph');
$icons['stm']['airplane'] = array("class"=>'airplane',"tags"=>'airplane');
$icons['stm']['compass'] = array("class"=>'compass',"tags"=>'compass');